import Adyen
import unittest
from Adyen import settings

try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest


class TestManagement(unittest.TestCase):
    adyen = Adyen.Adyen()

    client = adyen.client
    test = BaseTest(adyen)
    client.xapikey = "YourXapikey"
    client.platform = "test"
    balance_platform_url = adyen.balancePlatform.platform_api.baseUrl

    def test_creating_balance_account(self):
        request = {
            "accountHolderId": "AH32272223222B59K6ZKBBFNQ",
            "description": "S.Hopper - Main balance account"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/configuration/"
                                                              "balance-account-created.json")
        result = self.adyen.balancePlatform.balance_accounts_api.create_balance_account(request)
        self.assertEqual('AH32272223222B59K6ZKBBFNQ', result.message['accountHolderId'])
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.balance_platform_url}/balanceAccounts',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )

    def test_creating_account_holder(self):
        request = {
            "description": "Liable account holder used for international payments and payouts",
            "reference": "S.Eller-001",
            "legalEntityId": "LE322JV223222D5GG42KN6869"
        }
        self.adyen.client = self.test.create_client_from_file(200, request, "test/mocks/configuration/"
                                                                            "account-holder-created.json")
        result = self.adyen.balancePlatform.account_holders_api.create_account_holder(request)
        self.assertEqual("LE322JV223222D5GG42KN6869", result.message['legalEntityId'])
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.balance_platform_url}/accountHolders',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )

    def test_get_balance_platform(self):
        platform_id = "YOUR_BALANCE_PLATFORM"
        self.adyen.client = self.test.create_client_from_file(200, None, "test/mocks/configuration/"
                                                                         "balance-platform-retrieved.json")
        result = self.adyen.balancePlatform.platform_api.get_balance_platform(platform_id)
        self.assertEqual(platform_id, result.message['id'])
        self.adyen.client.http_client.request.assert_called_once_with(
            'GET',
            f'{self.balance_platform_url}/balancePlatforms/{platform_id}',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=None,
            xapikey="YourXapikey"
        )

    def test_creating_payment_instrument(self):
        request = {
            "type": "bankAccount",
            "description": "YOUR_DESCRIPTION",
            "balanceAccountId": "BA3227C223222B5CTBLR8BWJB",
            "issuingCountryCode": "NL"
        }
        self.adyen.client = self.test.create_client_from_file(200, request, "test/mocks/configuration/"
                                                                            "business-account-created.json")
        result = self.adyen.balancePlatform.payment_instruments_api.create_payment_instrument(request)
        self.assertEqual("BA3227C223222B5CTBLR8BWJB", result.message["balanceAccountId"])
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.balance_platform_url}/paymentInstruments',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )

    def test_creating_payment_instrument_group(self):
        request = {
            "balancePlatform": "YOUR_BALANCE_PLATFORM",
            "txVariant": "mc"
        }
        self.adyen.client = self.test.create_client_from_file(200, request, "test/mocks/configuration/"
                                                                            "payment-instrument-group-created.json")
        result = self.adyen.balancePlatform.payment_instrument_groups_api.create_payment_instrument_group(request)
        self.assertEqual("YOUR_BALANCE_PLATFORM", result.message['balancePlatform'])
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.balance_platform_url}/paymentInstrumentGroups',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )

    def test_get_transaction_rule(self):
        transactionRuleId = "TR32272223222B5CMD3V73HXG"
        self.adyen.client = self.test.create_client_from_file(200, {}, "test/mocks/configuration/"
                                                                       "transaction-rule-retrieved.json")
        result = self.adyen.balancePlatform.transaction_rules_api.get_transaction_rule(transactionRuleId)
        self.assertEqual(transactionRuleId, result.message['transactionRule']['id'])
        self.adyen.client.http_client.request.assert_called_once_with(
            'GET',
            f'{self.balance_platform_url}/'
            f'transactionRules/{transactionRuleId}',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=None,
            xapikey="YourXapikey"
        )



from ..base import AdyenServiceBase


class PayoutSettingsMerchantLevelApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(PayoutSettingsMerchantLevelApi, self).__init__(client=client)
        self.service = "management"
        self.baseUrl = "https://management-test.adyen.com/v3"

    def delete_payout_setting(self, merchantId, payoutSettingsId, idempotency_key=None, **kwargs):
        """
        Delete a payout setting
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/payoutSettings/{payoutSettingsId}"
        method = "DELETE"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def list_payout_settings(self, merchantId, idempotency_key=None, **kwargs):
        """
        Get a list of payout settings
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/payoutSettings"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_payout_setting(self, merchantId, payoutSettingsId, idempotency_key=None, **kwargs):
        """
        Get a payout setting
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/payoutSettings/{payoutSettingsId}"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def update_payout_setting(self, request, merchantId, payoutSettingsId, idempotency_key=None, **kwargs):
        """
        Update a payout setting
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/payoutSettings/{payoutSettingsId}"
        method = "PATCH"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def add_payout_setting(self, request, merchantId, idempotency_key=None, **kwargs):
        """
        Add a payout setting
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/payoutSettings"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




import Adyen
import unittest
from Adyen import settings

try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest


class TestManagement(unittest.TestCase):
    adyen = Adyen.Adyen()

    client = adyen.client
    test = BaseTest(adyen)
    client.xapikey = "YourXapikey"
    client.platform = "test"
    lem_url = adyen.legalEntityManagement.legal_entities_api.baseUrl

    def test_creating_legal_entity(self):
        request = {
            "type": "individual",
            "individual": {
                "residentialAddress": {
                    "city": "Amsterdam",
                    "country": "NL",
                    "postalCode": "1011DJ",
                    "street": "Simon Carmiggeltstraat 6 - 50"
                },
                "name": {
                    "firstName": "Shelly",
                    "lastName": "Eller"
                },
                "birthData": {
                    "dateOfBirth": "1990-06-21"
                },
                "email": "s.eller@example.com"
            }
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/legalEntityManagement/"
                                                              "individual_legal_entity_created.json")
        result = self.adyen.legalEntityManagement.legal_entities_api.create_legal_entity(request)
        self.assertEqual('Shelly', result.message['individual']['name']['firstName'])
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.lem_url}/legalEntities',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )

    def test_get_transfer_instrument(self):
        instrumentId = "SE322JV223222F5GNXSR89TMW"
        self.adyen.client = self.test.create_client_from_file(200, None, "test/mocks/legalEntityManagement/"
                                                                         "details_of_trainsfer_instrument.json")
        result = self.adyen.legalEntityManagement.transfer_instruments_api.get_transfer_instrument(instrumentId)
        self.assertEqual(instrumentId, result.message['id'])
        self.adyen.client.http_client.request.assert_called_once_with(
            'GET',
            f'{self.lem_url}/transferInstruments/{instrumentId}',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=None,
            xapikey="YourXapikey"
        )

    def test_update_business_line(self):
        businessLineId = "SE322JV223222F5GVGMLNB83F"
        request = {
            "industryCode": "55",
            "webData": [
                {
                    "webAddress": "https://www.example.com"
                }
            ]
        }
        self.adyen.client = self.test.create_client_from_file(200, request, "test/mocks/legalEntityManagement/"
                                                                            "business_line_updated.json")
        result = self.adyen.legalEntityManagement.business_lines_api.update_business_line(request, businessLineId)
        self.assertEqual(businessLineId, result.message['id'])
        self.adyen.client.http_client.request.assert_called_once_with(
            'PATCH',
            f'{self.lem_url}/businessLines/{businessLineId}',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )

    def test_accept_terms_of_service(self):
        legalEntityId = "legalId"
        documentId = "documentId"
        request = {
            'acceptedBy': "UserId",
            'ipAddress': "UserIpAddress"
        }
        self.adyen.client = self.test.create_client_from_file(204, request)
        self.adyen.legalEntityManagement.terms_of_service_api.accept_terms_of_service(request, legalEntityId,
                                                                                      documentId)
        self.adyen.client.http_client.request.assert_called_once_with(
            'PATCH',
            f'{self.lem_url}/legalEntities/{legalEntityId}/termsOfService/{documentId}',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )



from ..base import AdyenServiceBase


class TerminalSettingsMerchantLevelApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(TerminalSettingsMerchantLevelApi, self).__init__(client=client)
        self.service = "management"
        self.baseUrl = "https://management-test.adyen.com/v3"

    def get_terminal_logo(self, merchantId, idempotency_key=None, **kwargs):
        """
        Get the terminal logo
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/terminalLogos"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_terminal_settings(self, merchantId, idempotency_key=None, **kwargs):
        """
        Get terminal settings
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/terminalSettings"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def update_terminal_logo(self, request, merchantId, idempotency_key=None, **kwargs):
        """
        Update the terminal logo
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/terminalLogos"
        method = "PATCH"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def update_terminal_settings(self, request, merchantId, idempotency_key=None, **kwargs):
        """
        Update terminal settings
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/terminalSettings"
        method = "PATCH"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




from ..base import AdyenServiceBase


class ModificationsApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(ModificationsApi, self).__init__(client=client)
        self.service = "payments"
        self.baseUrl = "https://pal-test.adyen.com/pal/servlet/Payment/v68"

    def adjust_authorisation(self, request, idempotency_key=None, **kwargs):
        """
        Change the authorised amount
        """
        endpoint = self.baseUrl + f"/adjustAuthorisation"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def cancel(self, request, idempotency_key=None, **kwargs):
        """
        Cancel an authorisation
        """
        endpoint = self.baseUrl + f"/cancel"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def cancel_or_refund(self, request, idempotency_key=None, **kwargs):
        """
        Cancel or refund a payment
        """
        endpoint = self.baseUrl + f"/cancelOrRefund"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def capture(self, request, idempotency_key=None, **kwargs):
        """
        Capture an authorisation
        """
        endpoint = self.baseUrl + f"/capture"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def donate(self, request, idempotency_key=None, **kwargs):
        """
        Create a donation
        """
        endpoint = self.baseUrl + f"/donate"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def refund(self, request, idempotency_key=None, **kwargs):
        """
        Refund a captured payment
        """
        endpoint = self.baseUrl + f"/refund"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def technical_cancel(self, request, idempotency_key=None, **kwargs):
        """
        Cancel an authorisation using your reference
        """
        endpoint = self.baseUrl + f"/technicalCancel"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def void_pending_refund(self, request, idempotency_key=None, **kwargs):
        """
        Cancel an in-person refund
        """
        endpoint = self.baseUrl + f"/voidPendingRefund"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




import unittest
import Adyen
from Adyen import settings

try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest


class TestTerminal(unittest.TestCase):
    adyen = Adyen.Adyen(username="YourWSUser",
                        password="YourWSPassword",
                        platform="test",
                        xapikey="YourXapikey")
    test = BaseTest(adyen)
    client = adyen.client
    terminal_url = adyen.terminal.baseUrl

    def test_assign_terminals(self):
        request = {
            "companyAccount": "YOUR_COMPANY_ACCOUNT",
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            "store": "YOUR_STORE",
            "terminals": [
                "P400Plus-275479597"
            ]
        }
        self.test.create_client_from_file(
            200, request, "test/mocks/terminal/assignTerminals.json"
        )
        result = self.adyen.terminal.assign_terminals(request=request)
        self.assertIn("P400Plus-275479597", result.message["results"])

        self.client.http_client.request.assert_called_once_with(
            "POST",
            f"{self.terminal_url}/assignTerminals",
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json={
                "companyAccount": "YOUR_COMPANY_ACCOUNT",
                "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
                "store": "YOUR_STORE",
                "terminals": [
                    "P400Plus-275479597"
                ]
            },
            xapikey="YourXapikey"
        )

    def test_assign_terminals_422(self):
        request = {
            "companyAccount": "YOUR_COMPANY_ACCOUNT",
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            "store": "YOUR_STORE",
            "terminals": [
                "P400Plus-123456789"
            ]
        }
        self.test.create_client_from_file(
            200, request, "test/mocks/terminal/assignTerminals-422.json"
        )
        result = self.adyen.terminal.assign_terminals(request=request)
        self.assertEqual(422, result.message["status"])
        self.assertEqual("000", result.message["errorCode"])
        self.assertEqual("Terminals not found: P400Plus-123456789", result.message["message"])
        self.assertEqual("validation", result.message["errorType"])

    def test_find_terminal(self):
        request = {
            "terminal": "P400Plus-275479597",
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT"
        }
        self.test.create_client_from_file(
            200, request, "test/mocks/terminal/findTerminal.json"
        )
        result = self.adyen.terminal.find_terminal(request=request)
        self.assertIn("P400Plus-275479597", result.message["terminal"])

        self.client.http_client.request.assert_called_once_with(
            "POST",
            f"{self.terminal_url}/findTerminal",
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json={
                "terminal": "P400Plus-275479597",
                "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            },
            xapikey="YourXapikey"
        )

    def test_find_terminal_422(self):
        request = {
            "terminal": "P400Plus-123456789"
        }
        self.test.create_client_from_file(
            200, request, "test/mocks/terminal/findTerminal-422.json"
        )
        result = self.adyen.terminal.find_terminal(request=request)
        self.assertEqual(422, result.message["status"])
        self.assertEqual("000", result.message["errorCode"])
        self.assertEqual("Terminal not found", result.message["message"])
        self.assertEqual("validation", result.message["errorType"])

    def test_get_stores_under_account(self):
        request = {
            "companyAccount": "YOUR_COMPANY_ACCOUNT",
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT"
        }
        self.test.create_client_from_file(
            200, request, "test/mocks/terminal/getStoresUnderAccount.json"
        )
        result = self.adyen.terminal.get_stores_under_account(request=request)
        self.assertEqual(result.message["stores"], [
            {
                "store": "YOUR_STORE",
                "description": "YOUR_STORE",
                "address": {
                    "city": "The City",
                    "countryCode": "NL",
                    "postalCode": "1234",
                    "streetAddress": "The Street"
                },
                "status": "Active",
                "merchantAccountCode": "YOUR_MERCHANT_ACCOUNT"
            }
        ])

        self.client.http_client.request.assert_called_once_with(
            "POST",
            f"{self.terminal_url}/getStoresUnderAccount",
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json={
               "companyAccount": "YOUR_COMPANY_ACCOUNT",
                "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            },
            xapikey="YourXapikey"
        )

    def test_get_terminal_details(self):
        request = {
            "terminal": "P400Plus-275479597",
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
        }

        self.test.create_client_from_file(
            200, request, "test/mocks/terminal/getTerminalDetails.json"
        )
        result = self.adyen.terminal.get_terminal_details(request=request)

        self.assertEqual(result.message["deviceModel"], "P400Plus")
        self.assertEqual(result.message["terminal"], "P400Plus-275479597")

        self.client.http_client.request.assert_called_once_with(
            "POST",
            f"{self.terminal_url}/getTerminalDetails",
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json={
                "terminal": "P400Plus-275479597",
                "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            },
            xapikey="YourXapikey"
        )

    def test_get_terminal_details_422(self):
        request = {
            "terminal": "P400Plus-123456789"
        }
        self.test.create_client_from_file(
            200, request, "test/mocks/terminal/getTerminalDetails-422.json"
        )
        result = self.adyen.terminal.get_terminal_details(request=request)
        self.assertEqual(422, result.message["status"])
        self.assertEqual("000", result.message["errorCode"])
        self.assertEqual("Terminal not found", result.message["message"])
        self.assertEqual("validation", result.message["errorType"])

    def test_get_terminals_under_account(self):
        request = {
            "companyAccount": "YOUR_COMPANY_ACCOUNT",
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT"
        }

        self.test.create_client_from_file(
            200, request, "test/mocks/terminal/getTerminalsUnderAccount.json"
        )
        result = self.adyen.terminal.get_terminals_under_account(request=request)

        self.assertEqual(result.message["merchantAccounts"], [
            {
                "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
                "inStoreTerminals": [
                    "P400Plus-275479597"
                ],
                "stores": [
                    {
                        "store": "YOUR_STORE",
                        "inStoreTerminals": [
                            "M400-401972715"
                        ]
                    }
                ]
            }
        ])

        self.client.http_client.request.assert_called_once_with(
            "POST",
            f"{self.terminal_url}/getTerminalsUnderAccount",
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json={
                "companyAccount": "YOUR_COMPANY_ACCOUNT",
                "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            },
            xapikey="YourXapikey"
        )

    def test_get_terminals_under_account_store(self):
        request = {
            "companyAccount": "YOUR_COMPANY_ACCOUNT",
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            "store": "YOUR_STORE"
        }

        self.test.create_client_from_file(
            200, request, "test/mocks/terminal/getTerminalsUnderAccount-store.json"
        )
        result = self.adyen.terminal.get_terminals_under_account(request=request)

        self.assertEqual(result.message["merchantAccounts"], [
            {
                "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
                "stores": [
                    {
                        "store": "YOUR_STORE",
                        "inStoreTerminals": [
                            "M400-401972715"
                        ]
                    }
                ]
            }
        ])

        self.client.http_client.request.assert_called_once_with(
            "POST",
            f"{self.terminal_url}/getTerminalsUnderAccount",
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json={
                "companyAccount": "YOUR_COMPANY_ACCOUNT",
                "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
                "store": "YOUR_STORE",
            },
            xapikey="YourXapikey"
        )


TestTerminal.client.http_force = "requests"
suite = unittest.TestLoader().loadTestsFromTestCase(TestTerminal)
unittest.TextTestRunner(verbosity=2).run(suite)

TestTerminal.client.http_force = "pycurl"
TestTerminal.client.http_init = False
suite = unittest.TestLoader().loadTestsFromTestCase(TestTerminal)
unittest.TextTestRunner(verbosity=2).run(suite)

TestTerminal.client.http_force = "other"
TestTerminal.client.http_init = False
suite = unittest.TestLoader().loadTestsFromTestCase(TestTerminal)
unittest.TextTestRunner(verbosity=2).run(suite)



from ..base import AdyenServiceBase


class TerminalOrdersMerchantLevelApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(TerminalOrdersMerchantLevelApi, self).__init__(client=client)
        self.service = "management"
        self.baseUrl = "https://management-test.adyen.com/v3"

    def list_billing_entities(self, merchantId, idempotency_key=None, **kwargs):
        """
        Get a list of billing entities
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/billingEntities"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def list_shipping_locations(self, merchantId, idempotency_key=None, **kwargs):
        """
        Get a list of shipping locations
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/shippingLocations"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def list_terminal_models(self, merchantId, idempotency_key=None, **kwargs):
        """
        Get a list of terminal models
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/terminalModels"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def list_orders(self, merchantId, idempotency_key=None, **kwargs):
        """
        Get a list of orders
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/terminalOrders"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_order(self, merchantId, orderId, idempotency_key=None, **kwargs):
        """
        Get an order
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/terminalOrders/{orderId}"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def list_terminal_products(self, merchantId, idempotency_key=None, **kwargs):
        """
        Get a list of terminal products
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/terminalProducts"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def update_order(self, request, merchantId, orderId, idempotency_key=None, **kwargs):
        """
        Update an order
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/terminalOrders/{orderId}"
        method = "PATCH"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def create_shipping_location(self, request, merchantId, idempotency_key=None, **kwargs):
        """
        Create a shipping location
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/shippingLocations"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def create_order(self, request, merchantId, idempotency_key=None, **kwargs):
        """
        Create an order
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/terminalOrders"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def cancel_order(self, merchantId, orderId, idempotency_key=None, **kwargs):
        """
        Cancel an order
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/terminalOrders/{orderId}/cancel"
        method = "POST"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)




from ..base import AdyenServiceBase
from .account_holders_api import AccountHoldersApi
from .balance_accounts_api import BalanceAccountsApi
from .bank_account_validation_api import BankAccountValidationApi
from .grant_accounts_api import GrantAccountsApi
from .grant_offers_api import GrantOffersApi
from .network_tokens_api import NetworkTokensApi
from .payment_instrument_groups_api import PaymentInstrumentGroupsApi
from .payment_instruments_api import PaymentInstrumentsApi
from .platform_api import PlatformApi
from .transaction_rules_api import TransactionRulesApi
from .transfer_routes_api import TransferRoutesApi


class AdyenBalancePlatformApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenBalancePlatformApi, self).__init__(client=client)
        self.account_holders_api = AccountHoldersApi(client=client)
        self.balance_accounts_api = BalanceAccountsApi(client=client)
        self.bank_account_validation_api = BankAccountValidationApi(client=client)
        self.grant_accounts_api = GrantAccountsApi(client=client)
        self.grant_offers_api = GrantOffersApi(client=client)
        self.network_tokens_api = NetworkTokensApi(client=client)
        self.payment_instrument_groups_api = PaymentInstrumentGroupsApi(client=client)
        self.payment_instruments_api = PaymentInstrumentsApi(client=client)
        self.platform_api = PlatformApi(client=client)
        self.transaction_rules_api = TransactionRulesApi(client=client)
        self.transfer_routes_api = TransferRoutesApi(client=client)



from .base import AdyenServiceBase


class AdyenStoredValueApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenStoredValueApi, self).__init__(client=client)
        self.service = "storedValue"
        self.baseUrl = "https://pal-test.adyen.com/pal/servlet/StoredValue/v46"

    def change_status(self, request, idempotency_key=None, **kwargs):
        """
        Changes the status of the payment method.
        """
        endpoint = self.baseUrl + f"/changeStatus"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def check_balance(self, request, idempotency_key=None, **kwargs):
        """
        Checks the balance.
        """
        endpoint = self.baseUrl + f"/checkBalance"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def issue(self, request, idempotency_key=None, **kwargs):
        """
        Issues a new card.
        """
        endpoint = self.baseUrl + f"/issue"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def load(self, request, idempotency_key=None, **kwargs):
        """
        Loads the payment method.
        """
        endpoint = self.baseUrl + f"/load"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def merge_balance(self, request, idempotency_key=None, **kwargs):
        """
        Merge the balance of two cards.
        """
        endpoint = self.baseUrl + f"/mergeBalance"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def void_transaction(self, request, idempotency_key=None, **kwargs):
        """
        Voids a transaction.
        """
        endpoint = self.baseUrl + f"/voidTransaction"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




from ..base import AdyenServiceBase


class DocumentsApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(DocumentsApi, self).__init__(client=client)
        self.service = "legalEntityManagement"
        self.baseUrl = "https://kyc-test.adyen.com/lem/v3"

    def delete_document(self, id, idempotency_key=None, **kwargs):
        """
        Delete a document
        """
        endpoint = self.baseUrl + f"/documents/{id}"
        method = "DELETE"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_document(self, id, idempotency_key=None, **kwargs):
        """
        Get a document
        """
        endpoint = self.baseUrl + f"/documents/{id}"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def update_document(self, request, id, idempotency_key=None, **kwargs):
        """
        Update a document
        """
        endpoint = self.baseUrl + f"/documents/{id}"
        method = "PATCH"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def upload_document_for_verification_checks(self, request, idempotency_key=None, **kwargs):
        """
        Upload a document for verification checks
        """
        endpoint = self.baseUrl + f"/documents"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

